==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/nl.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Album",
    "There was a problem reading files from this album" : "Er was een probleem met het laden van bestanden van dit album",
    "Aborting preview. Could not find the file" : "Voorvertoning afgebroken. Kon het bestand niet vinden",
    "Could not move \"{file}\", target exists" : "Kon \"{file}\" niet verplaatsen, doel bestaat al",
    "Could not move \"{file}\"" : "Kon \"{file}\" niet verplaatsen",
    "No compatible server found at {remote}" : "Geen geschikte server gevonden op {remote}",
    "Invalid server url" : "Ongeldige server url",
    "Could not load the description" : "Kon de beschrijving niet laden",
    "Could not load the description: " : "Kon de beschrijving niet laden:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Kon de copyright melding niet laden:",
    "Copyright notice" : "Copyright-melding",
    "Link to copyright document" : "Link naar copyright document",
    "This application may not work properly on your browser." : "Dit programma zou niet goed kunnen werken in je browser.",
    "For an improved experience, please install one of the following alternatives" : "Voor een betere ervaring, installeert u één van de volgende alternatieven",
    "Your browser is not supported!" : "Je browser wordt niet ondersteund!",
    "please install one of the following alternatives" : "Installeer één van de volgende alternatieven",
    "Album cannot be shown" : "Album kan niet worden getoond",
    "No media files found" : "Geen mediabestanden gevonden",
    "Upload pictures in the Files app to display them here" : "Upload afbeeldingen in de bestandsapp, om ze hier te tonen",
    "Upload new files via drag and drop or by using the [+] button above" : "Upload nieuwe bestanden via drag 'n drop of door gebruik van de  [+] knop hierboven",
    "Configuration error" : "Configuratiefout",
    "New" : "Nieuw",
    "Hide Album" : "Verbergen album",
    "Could not hide album" : "Kon album niet verbergen",
    "Error loading slideshow template" : "Fout bij laden diashow sjabloon",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Fout!</strong> Kon geen voorbeeld van die bestand genereren.<br>Ga naar de volgende dia, terwijl we deze afbeelding uit de diashow verwijderen",
    "Next" : "Volgende",
    "Play" : "Afspelen",
    "Pause" : "Pauze",
    "Previous" : "Vorige",
    "Close" : "Sluiten",
    "Download" : "Downloaden",
    "Toggle background" : "Achtergrond omschakelen",
    "Delete" : "Verwijderen",
    "Could not create file \"{file}\" because it already exists" : "Kon \"{file}\" niet aanmaken, omdat het al bestaat",
    "Could not create file \"{file}\"" : "Kon \"{file}\" niet aanmaken",
    "\"{name}\" is an invalid file name." : "\"{name}\" is een ongeldige bestandsnaam.",
    "File name cannot be empty." : "Bestandsnaam kan niet leeg zijn.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" is een niet toegestaan bestandstype",
    "Upload" : "Uploaden",
    "Error" : "Fout",
    "Error while sharing" : "Fout tijdens het delen",
    "Error while unsharing" : "Fout tijdens het stoppen met delen",
    "Error while changing permissions" : "Fout tijdens het veranderen van permissies",
    "Shared with you and the group {group} by {owner}" : "Gedeeld met u en de groep {group} door {owner}",
    "Shared with you by {owner}" : "Gedeeld met u door {owner}",
    "Share with users or groups …" : "Delen met gebruikers of groepen ...",
    "Share with users, groups or remote users …" : "Delen met gebruikers, groepen of externe gebruikers ...",
    "Share" : "Delen",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Delen met mensen bij andere servers via hun gefedereerde Cloud ID gebruikersnaam@voorbeeld.nl/nextcloud",
    "Share link" : "Deel link",
    "The public link will expire no later than {days} days after it is created" : "De openbare link vervalt niet eerder dan {days} dagen na het aanmaken",
    "Link" : "Link",
    "Password protect" : "Wachtwoord beveiligd",
    "Password" : "Wachtwoord",
    "Choose a password for the public link" : "Kies een wachtwoord voor de openbare link",
    "Allow editing" : "Toestaan bewerken",
    "Email link to person" : "E-mail link naar persoon",
    "Send" : "Versturen",
    "Set expiration date" : "Vervaldatum instellen",
    "Expiration" : "Vervaltermijn",
    "Expiration date" : "Vervaldatum",
    "This list is maybe truncated - please refine your search term to see more results." : "Deze lijst is misschien afgekapt - verfijn de zoekterm om meer resultaten te zien.",
    "No users or groups found for {search}" : "Geen gebruikers of groepen gevonden voor {search}",
    "No users found for {search}" : "Geen gebruikers gevonden voor {search}",
    "An error occured. Please try again" : "Er trad een fout op. Probeer het opnieuw",
    "Adding user..." : "Gebruiker toevoegen...",
    "group" : "groep",
    "remote" : "extern",
    "Resharing is not allowed" : "Verder delen is niet toegestaan",
    "Error while retrieving shares" : "Fout bij het ontvangen van shares",
    "Unshare" : "Stop met delen",
    "notify by email" : "per e-mail melden",
    "can share" : "kan delen",
    "can edit" : "kan wijzigen",
    "access control" : "toegangscontrole",
    "create" : "creëer",
    "change" : "wijzig",
    "delete" : "verwijderen",
    "Password protected" : "Wachtwoord beveiligd",
    "Error unsetting expiration date" : "Fout tijdens het verwijderen van de vervaldatum",
    "Error setting expiration date" : "Fout tijdens het instellen van de vervaldatum",
    "Sending ..." : "Versturen ...",
    "Email sent" : "E-mail verzonden",
    "Warning" : "Waarschuwing",
    "This share is password-protected" : "Deze share is met een wachtwoord beveiligd",
    "The password is wrong. Try again." : "Wachtwoord ongeldig. Probeer het nogmaals.",
    "Sort by date" : "Sorteer op datum",
    "Sort by name" : "Sorteer op naam",
    "Cancel upload" : "Upload afbreken",
    "Album information" : "Album-informatie",
    "File list" : "Bestandenlijst",
    "Sorry, this file could not be found." : "Sorry, dit bestand kon niet worden gevonden",
    "Reasons might be:" : "Redenen kunnen zijn:",
    "the wrong file ID was provided" : "verkeerde bestand-ID werd gegeven",
    "the file was removed" : "bestand was verplaatst",
    "the file is corrupt" : "bestand is beschadigd",
    "the encryption key is missing" : "de encryptiesleutel ontbreekt",
    "Here is the error message returned by the server: " : "Hier is de foutmelding van de server:",
    "For more information, please contact your friendly Nextcloud administrator." : "Voor meer informatie neem je contact op met je Nextcloud beheerder.",
    "Sorry, but the server could not fulfill your request." : "Sorry, maar de server kon je opdracht niet uitvoeren.",
    "Possible reasons for the problem:" : "Mogelijke oorzaken voor het probleem:",
    "a conflicting app was installed" : "een conflicteren app was geinstalleerd",
    "a required component is missing or was disconnected" : "een vereist onderdeel ontbreekt of is losgekoppeld",
    "the filesystem is not readable" : "het bestandssysteem is niet leesbaar",
    "Sorry, this link doesn't seem to work anymore." : "Sorry, deze link lijkt niet meer in gebruik te zijn.",
    "the item was removed" : "bestand was verwijderd",
    "the link has expired" : "link is verlopen",
    "sharing is disabled" : "delen is uitgeschakeld",
    "For more information, please ask the person who has sent you this link." : "Voor meer informatie, neem contact op met de persoon die u deze link heeft gestuurd.",
    "Add to your Nextcloud" : "Toevoegen aan je Nextcloud",
    "Picture view" : "Afbeeldingenoverzicht",
    "Gallery view" : "Album"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/nl.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Album",
    "There was a problem reading files from this album" : "Er was een probleem met het laden van bestanden van dit album",
    "Aborting preview. Could not find the file" : "Voorvertoning afgebroken. Kon het bestand niet vinden",
    "Could not move \"{file}\", target exists" : "Kon \"{file}\" niet verplaatsen, doel bestaat al",
    "Could not move \"{file}\"" : "Kon \"{file}\" niet verplaatsen",
    "No compatible server found at {remote}" : "Geen geschikte server gevonden op {remote}",
    "Invalid server url" : "Ongeldige server url",
    "Could not load the description" : "Kon de beschrijving niet laden",
    "Could not load the description: " : "Kon de beschrijving niet laden:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Kon de copyright melding niet laden:",
    "Copyright notice" : "Copyright-melding",
    "Link to copyright document" : "Link naar copyright document",
    "This application may not work properly on your browser." : "Dit programma zou niet goed kunnen werken in je browser.",
    "For an improved experience, please install one of the following alternatives" : "Voor een betere ervaring, installeer je één van de volgende alternatieven",
    "Your browser is not supported!" : "Je browser wordt niet ondersteund!",
    "please install one of the following alternatives" : "Installeer één van de volgende alternatieven",
    "Album cannot be shown" : "Album kan niet worden getoond",
    "No media files found" : "Geen mediabestanden gevonden",
    "Upload pictures in the Files app to display them here" : "Upload afbeeldingen in de bestandsapp, om ze hier te tonen",
    "Upload new files via drag and drop or by using the [+] button above" : "Upload nieuwe bestanden via drag 'n drop of door gebruik van de  [+] knop hierboven",
    "Configuration error" : "Configuratiefout",
    "New" : "Nieuw",
    "Hide Album" : "Verberg album",
    "Could not hide album" : "Kon album niet verbergen",
    "Error loading slideshow template" : "Fout bij laden diashow sjabloon",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Fout!</strong> Kon geen voorbeeld van die bestand genereren.<br>Ga naar de volgende dia, terwijl we deze afbeelding uit de diashow verwijderen",
    "Next" : "Volgende",
    "Play" : "Afspelen",
    "Pause" : "Pauze",
    "Previous" : "Vorige",
    "Close" : "Sluiten",
    "Download" : "Downloaden",
    "Toggle background" : "Achtergrond omschakelen",
    "Delete" : "Verwijderen",
    "Share" : "Delen",
    "Could not create file \"{file}\" because it already exists" : "Kon \"{file}\" niet aanmaken, omdat het al bestaat",
    "Could not create file \"{file}\"" : "Kon \"{file}\" niet aanmaken",
    "\"{name}\" is an invalid file name." : "\"{name}\" is een ongeldige bestandsnaam.",
    "File name cannot be empty." : "Bestandsnaam kan niet leeg zijn.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" is een niet toegestaan bestandstype",
    "Upload" : "Uploaden",
    "Error" : "Fout",
    "Error while sharing" : "Fout tijdens het delen",
    "Error while unsharing" : "Fout tijdens het stoppen met delen",
    "Error while changing permissions" : "Fout tijdens het veranderen van permissies",
    "Shared with you and the group {group} by {owner}" : "Met jou en de groep {group} gedeeld door {owner}",
    "Shared with you by {owner}" : "Met je gedeeld door {owner}",
    "Share with users or groups …" : "Delen met gebruikers of groepen ...",
    "Share with users, groups or remote users …" : "Delen met gebruikers, groepen of externe gebruikers ...",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Delen met mensen bij andere servers via hun gefedereerde Cloud ID gebruikersnaam@voorbeeld.nl/nextcloud",
    "Share link" : "Deel link",
    "The public link will expire no later than {days} days after it is created" : "De openbare link vervalt niet eerder dan {days} dagen na het aanmaken",
    "Link" : "Link",
    "Password protect" : "Wachtwoord beveiligd",
    "Password" : "Wachtwoord",
    "Choose a password for the public link" : "Kies een wachtwoord voor de openbare link",
    "Allow editing" : "Toestaan bewerken",
    "Email link to person" : "E-mail link naar persoon",
    "Send" : "Versturen",
    "Set expiration date" : "Vervaldatum instellen",
    "Expiration" : "Vervaltermijn",
    "Expiration date" : "Vervaldatum",
    "This list is maybe truncated - please refine your search term to see more results." : "Deze lijst is misschien afgekapt - verfijn de zoekterm om meer resultaten te zien.",
    "No users or groups found for {search}" : "Geen gebruikers of groepen gevonden voor {search}",
    "No users found for {search}" : "Geen gebruikers gevonden voor {search}",
    "An error occured. Please try again" : "Er trad een fout op. Probeer het opnieuw",
    "Adding user..." : "Gebruiker toevoegen...",
    "group" : "groep",
    "remote" : "extern",
    "Resharing is not allowed" : "Verder delen is niet toegestaan",
    "Error while retrieving shares" : "Fout bij het ontvangen van shares",
    "Unshare" : "Stop met delen",
    "notify by email" : "per e-mail melden",
    "can share" : "kan delen",
    "can edit" : "kan wijzigen",
    "access control" : "toegangscontrole",
    "create" : "creëer",
    "change" : "wijzig",
    "delete" : "verwijderen",
    "Password protected" : "Wachtwoord beveiligd",
    "Error unsetting expiration date" : "Fout tijdens het verwijderen van de vervaldatum",
    "Error setting expiration date" : "Fout tijdens het instellen van de vervaldatum",
    "Sending ..." : "Versturen ...",
    "Email sent" : "E-mail verzonden",
    "Warning" : "Waarschuwing",
    "This share is password-protected" : "Deze share is met een wachtwoord beveiligd",
    "The password is wrong. Try again." : "Wachtwoord ongeldig. Probeer het nogmaals.",
    "Sort by name" : "Sorteer op naam",
    "Sort by date" : "Sorteer op datum",
    "Cancel upload" : "Upload afbreken",
    "Album information" : "Album-informatie",
    "File list" : "Bestandenlijst",
    "Sorry, this file could not be found." : "Sorry, dit bestand kon niet worden gevonden",
    "Reasons might be:" : "Redenen kunnen zijn:",
    "the wrong file ID was provided" : "verkeerde bestand-ID werd gegeven",
    "the file was removed" : "bestand was verplaatst",
    "the file is corrupt" : "bestand is beschadigd",
    "the encryption key is missing" : "de encryptiesleutel ontbreekt",
    "Here is the error message returned by the server: " : "Hier is de foutmelding van de server:",
    "For more information, please contact your friendly Nextcloud administrator." : "Voor meer informatie neem je contact op met je Nextcloud beheerder.",
    "Sorry, but the server could not fulfill your request." : "Sorry, maar de server kon je opdracht niet uitvoeren.",
    "Possible reasons for the problem:" : "Mogelijke oorzaken voor het probleem:",
    "a conflicting app was installed" : "een conflicteren app was geinstalleerd",
    "a required component is missing or was disconnected" : "een vereist onderdeel ontbreekt of is losgekoppeld",
    "the filesystem is not readable" : "het bestandssysteem is niet leesbaar",
    "Sorry, this link doesn't seem to work anymore." : "Sorry, deze link lijkt niet meer in gebruik te zijn.",
    "the item was removed" : "bestand was verwijderd",
    "the link has expired" : "link is verlopen",
    "sharing is disabled" : "delen is uitgeschakeld",
    "For more information, please ask the person who has sent you this link." : "Voor meer informatie, neem contact op met de persoon die je deze link heeft gestuurd.",
    "Add to your Nextcloud" : "Toevoegen aan je Nextcloud",
    "Picture view" : "Afbeeldingenoverzicht",
    "Gallery view" : "Album"
},
"nplurals=2; plural=(n != 1);");
